@@ -6,7 +6,6 @@ use strict;
 use utf8;
 use warnings;
 
-use List::Util qw(max);
 use Unicode::GCString;
 
 require Exporter;
@@ -16,13 +15,14 @@ our @EXPORT_OK = qw(
                        pad
                        mbswidth
                        mbswidth_height
+                       length_height
                        mbtrunc
                        trunc
                        mbwrap
                        wrap
                );
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 sub mbswidth {
     Unicode::GCString->new($_[0])->columns;
@@ -31,16 +31,33 @@ sub mbswidth {
 sub mbswidth_height {
     my $text = shift;
     my $num_lines = 0;
-    my @lens;
+    my $len = 0;
     for my $e (split /(\r?\n)/, $text) {
         if ($e =~ /\n/) {
             $num_lines++;
             next;
         }
         $num_lines = 1 if $num_lines == 0;
-        push @lens, mbswidth($e);
+        my $l = mbswidth($e);
+        $len = $l if $len < $l;
     }
-    [max(@lens) // 0, $num_lines];
+    [$len, $num_lines];
+}
+
+sub length_height {
+    my $text = shift;
+    my $num_lines = 0;
+    my $len = 0;
+    for my $e (split /(\r?\n)/, $text) {
+        if ($e =~ /\n/) {
+            $num_lines++;
+            next;
+        }
+        $num_lines = 1 if $num_lines == 0;
+        my $l = length($e);
+        $len = $l if $len < $l;
+    }
+    [$len, $num_lines];
 }
 
 sub _get_indent_width {
@@ -398,7 +415,7 @@ Text::WideChar::Util - Routines for text containing wide characters
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -438,6 +455,11 @@ Unicode::GCString->new($text)->columns >>.
 Like mbswidth(), but also gives height (number of lines). For example, C<<
 mbswidth_height("foobar\nb\n") >> gives [6, 3].
 
+=head2 length_height($text) => [INT, INT]
+
+This is the non-wide version of mbswidth_height() and can be used if your text
+only contains printable ASCII characters and newlines.
+
 =head2 mbwrap($text, $width, \%opts) => STR
 
 Wrap C<$text> to C<$width> columns. It uses mbswidth() instead of Perl's
